// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include "PinguSpotMap.hh"

PinguSpotMap::PinguSpotMap()
{
}

// The complete load function should be thrown away and be placed here
PinguSpotMap::PinguSpotMap(ResDescriptor name, CL_ResourceManager *res)
{
  switch(name.type) {
    case ResDescriptor::RESOURCE:
      cout << "PinguSpotMap: ResType RESOURCE is not implemented, sorry" << endl;
      exit(EXIT_FAILURE);
      break;
    case ResDescriptor::FILE:
      load(name.res_name.c_str(), res);
      break;
  }
}

PinguSpotMap::~PinguSpotMap(void)
{
}

// Load the map from a *.psm (Pingu Spot Map) file and load the surfaces
int
PinguSpotMap::load(const char* filename, CL_ResourceManager* resource)
{
  surface_data temp;
  ifstream in(filename);

  if (!in) {
    return false;
  }

  in >> width;
  in >> height;
  
  while(!in.eof()) {
    in >> temp.name;
    in >> temp.x_pos;
    in >> temp.y_pos;
   
    if (in.eof())
      continue;

    temp.surface = CL_Res_Surface::load(temp.name.c_str(), *resource);

    surfaces.push_back(temp);
  }

  return true;
}

// Draws the map with a offset, needed for scrolling
void
PinguSpotMap::draw_offset(int of_x, int of_y, double s)
{
  if (s == 1.0) {
    for(unsigned int i=0; i < surfaces.size(); ++i) 
      surfaces[i].surface->put_screen(surfaces[i].x_pos + of_x,
				      surfaces[i].y_pos + of_y);
  } else {
    for(unsigned int i=0; i < surfaces.size(); ++i) 
      surfaces[i].surface->put_screen((int)((surfaces[i].x_pos + of_x) * s),
				      (int)((surfaces[i].y_pos + of_y) * s),
				      (int)(surfaces[i].surface->get_width() * s),
				      (int)(surfaces[i].surface->get_height() * s)
				      );
  }
}

// Returns the width of the map, it is read directly from the *.psm file
int
PinguSpotMap::get_width(void)
{
  return width;
}

// Returns the height of the map, it is read directly from the *.psm file
int 
PinguSpotMap::get_height(void)
{
  return height;
}

ColMap*
PinguSpotMap::get_colmap(void)
{
  cout << "PinguSpotMap: Staring ColMap creation" << endl;
  ColMap* col;
  unsigned char* buffer;

  // Allocate the space for the colmap buffer
  buffer = new unsigned char[width * height];

  cout << "PinguSpotMap: Clearing buffer" << endl;
  for(int i=0; i < width * height; ++i) {
    buffer[i] = 0;
  }

  // Create a empty ColMap
  col = new ColMap(buffer, width, height);

  for(unsigned int i=0; i < surfaces.size(); ++i) {
    cout << "Putting surface";
    col->put(surfaces[i].surface, surfaces[i].x_pos, surfaces[i].y_pos);
  }
  cout << "Returning ColMap" << endl;
  return col;
}

/* EOF */
