// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include "basher.hh"
#include "../particles/GroundParticle.hh"
#include "../algo.hh"

PinguAction* 
make_Basher()
{
  return new Basher;
}

Basher::Basher()
{
}

void
Basher::init(void)
{
  surface = CL_Res_Surface::load("Pingus/basher", *local_res());

  counter.set_size(surface->get_no_sprs() / 2);
  counter.set_type(Counter::loop);
  counter.set_count(0);
  counter.set_speed(1);

  basher_c.set_size(4);
  basher_c.set_count(0);

  is_multi_direct = true;
}

void
Basher::let_move()
{
  if (++basher_c >= 3) {
    for (int y1 = pingu->y_pos-31; y1 <= pingu->y_pos; ++y1) {
      pingu->colmap->remove(pingu->x_pos + pingu->direction, y1);
      pingu->map->remove(pingu->x_pos + pingu->direction, y1);
    }
    pingu->x_pos += pingu->direction;
  }

  pingu->particle->add_particle(new GroundParticle(pingu->x_pos,
					       pingu->y_pos,
					       frand() * -4 * pingu->direction,
					       frand() * -3));

  if (rel_getpixel(1, 0) == ColMap::AIR)
    is_finished = true;
}

/* EOF */
